"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _config = require("../../config");
var _errors = require("../../services/errors");
var _http = require("../../services/http");
function asyncGeneratorStep(n, t, e, r, o, a, c) { try { var i = n[a](c), u = i.value; } catch (n) { return void e(n); } i.done ? t(u) : Promise.resolve(u).then(r, o); }
function _asyncToGenerator(n) { return function () { var t = this, e = arguments; return new Promise(function (r, o) { var a = n.apply(t, e); function _next(n) { asyncGeneratorStep(a, r, o, _next, _throw, "next", n); } function _throw(n) { asyncGeneratorStep(a, r, o, _next, _throw, "throw", n); } _next(void 0); }); }; }
/**
 * Class dealing with the /balances endpoint
 *
 * @export
 * @class Balances
 */
class Balances {
  constructor(config) {
    this.config = config;
  }

  /**
   * Use this endpoint to retrieve balances for each currency account belonging to an entity.
   *
   * @memberof Balances
   * @param {string} id The ID of the entity.
   * @param {string} currency The query to apply to limit the currency accounts.
   * @return {Promise<Object>} A promise to the balances response.
   */
  retrieve(id, currency) {
    var _this = this;
    return _asyncToGenerator(function* () {
      try {
        const url = `${_this.config.host.includes('sandbox') ? _config.BALANCES_SANDBOX_URL : _config.BALANCES_LIVE_URL}/${id}${currency ? `?query=currency:${currency}` : ''}`;
        const response = yield (0, _http.get)(_this.config.httpClient, url, _this.config, _this.config.sk);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }
}
exports.default = Balances;
//# sourceMappingURL=balances.js.map