"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _errors = require("../../services/errors");
var _http = require("../../services/http");
function asyncGeneratorStep(n, t, e, r, o, a, c) { try { var i = n[a](c), u = i.value; } catch (n) { return void e(n); } i.done ? t(u) : Promise.resolve(u).then(r, o); }
function _asyncToGenerator(n) { return function () { var t = this, e = arguments; return new Promise(function (r, o) { var a = n.apply(t, e); function _next(n) { asyncGeneratorStep(a, r, o, _next, _throw, "next", n); } function _throw(n) { asyncGeneratorStep(a, r, o, _next, _throw, "throw", n); } _next(void 0); }); }; }
/**
 * Class dealing with the /customers endpoint
 *
 * @export
 * @class Customers
 */
class Customers {
  constructor(config) {
    this.config = config;
  }

  /**
   * Create a customer
   *
   * @memberof Customers
   * @param {Object} customer Customer object body.
   * @return {Promise<Object>} A promise to the create customer response.
   */
  create(customer) {
    var _this = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.post)(_this.config.httpClient, `${_this.config.host}/customers`, _this.config, _this.config.sk, customer);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }

  /**
   * Get a customer
   *
   * @memberof Customers
   * @param {string} id Customer id.
   * @return {Promise<Object>} A promise to the customer details response.
   */
  get(id) {
    var _this2 = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.get)(_this2.config.httpClient, `${_this2.config.host}/customers/${id}`, _this2.config, _this2.config.sk);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }

  /**
   * Update details of a customer
   *
   * @memberof Customers
   * @param {string} id Customer id.
   * @param {Object} body Customer object body.
   * @return {Promise<Object>} A promise to the request customer response.
   */
  update(id, body) {
    var _this3 = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.patch)(_this3.config.httpClient, `${_this3.config.host}/customers/${id}`, _this3.config, _this3.config.sk, body);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }

  /**
   * Delete a customer
   *
   * @memberof Customers
   * @param {string} id Customer id.
   * @return {Promise<Object>} A promise to the customer response.
   */
  delete(id) {
    var _this4 = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http._delete)(_this4.config.httpClient, `${_this4.config.host}/customers/${id}`, _this4.config, _this4.config.sk);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }
}
exports.default = Customers;
//# sourceMappingURL=customers.js.map