"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _errors = require("../../services/errors");
var _http = require("../../services/http");
var _utils = require("../../services/utils");
function asyncGeneratorStep(n, t, e, r, o, a, c) { try { var i = n[a](c), u = i.value; } catch (n) { return void e(n); } i.done ? t(u) : Promise.resolve(u).then(r, o); }
function _asyncToGenerator(n) { return function () { var t = this, e = arguments; return new Promise(function (r, o) { var a = n.apply(t, e); function _next(n) { asyncGeneratorStep(a, r, o, _next, _throw, "next", n); } function _throw(n) { asyncGeneratorStep(a, r, o, _next, _throw, "throw", n); } _next(void 0); }); }; }
/**
 * Class dealing with the forex api
 *
 * @export
 * @class Forex
 */
class Forex {
  constructor(config) {
    this.config = config;
  }

  /**
   * Request an exchange rate between a source and destination currency
   *
   * @param {Object} body Forex object body.
   * @return {Promise<Object>} A promise to the Forex response.
   */
  request(body) {
    var _this = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.post)(_this.config.httpClient, `${_this.config.host}/forex/quotes`, _this.config, _this.config.sk, body);
        return yield response.json;
      } catch (err) {
        throw yield (0, _errors.determineError)(err);
      }
    })();
  }

  /**
   * Use the Forex (FX) rates API to get the indicative foreign exchange rates that Checkout.com
   * uses to process payments for card payouts
   *
   * @param {Object} body Forex params.
   * @return {Promise<Object>} A promise to the Forex response.
   */
  getRates(body) {
    var _this2 = this;
    return _asyncToGenerator(function* () {
      try {
        const url = (0, _utils.buildQueryParams)(`${_this2.config.host}/forex/rates`, body);
        const response = yield (0, _http.get)(_this2.config.httpClient, url, _this2.config, _this2.config.sk);
        return yield response.json;
      } catch (err) {
        throw yield (0, _errors.determineError)(err);
      }
    })();
  }
}
exports.default = Forex;
//# sourceMappingURL=forex.js.map