"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _errors = require("../../services/errors");
var _http = require("../../services/http");
function asyncGeneratorStep(n, t, e, r, o, a, c) { try { var i = n[a](c), u = i.value; } catch (n) { return void e(n); } i.done ? t(u) : Promise.resolve(u).then(r, o); }
function _asyncToGenerator(n) { return function () { var t = this, e = arguments; return new Promise(function (r, o) { var a = n.apply(t, e); function _next(n) { asyncGeneratorStep(a, r, o, _next, _throw, "next", n); } function _throw(n) { asyncGeneratorStep(a, r, o, _next, _throw, "throw", n); } _next(void 0); }); }; }
/**
 * Class dealing with the /forward endpoint
 *
 * @export
 * @class Forward
 */
class Forward {
  constructor(config) {
    this.config = config;
  }

  /**
   * Beta
   * Forwards an API request to a third-party endpoint.
   * For example, you can forward payment credentials you've stored in our Vault to a third-party payment processor.
   *
   * Forward an API request
   * @param {Object} body Forward request body
   * @return {Promise<Object>} A promise to the forward response
   */
  forwardRequest(body) {
    var _this = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.post)(_this.config.httpClient, `${_this.config.host}/forward`, _this.config, _this.config.sk, body);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }

  /**
   * Retrieve the details of a successfully forwarded API request.
   * The details can be retrieved for up to 14 days after the request was initiated.
   *
   * Get forward request
   * @param {string} id The unique identifier of the forward request
   * @return {Promise<Object>} A promise to the forward request details
   */
  get(id) {
    var _this2 = this;
    return _asyncToGenerator(function* () {
      try {
        const response = yield (0, _http.get)(_this2.config.httpClient, `${_this2.config.host}/forward/${id}`, _this2.config, _this2.config.sk);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }
}
exports.default = Forward;
//# sourceMappingURL=forward.js.map