"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _errors = require("../../services/errors");
var _http = require("../../services/http");
var _config = require("../../config");
function asyncGeneratorStep(n, t, e, r, o, a, c) { try { var i = n[a](c), u = i.value; } catch (n) { return void e(n); } i.done ? t(u) : Promise.resolve(u).then(r, o); }
function _asyncToGenerator(n) { return function () { var t = this, e = arguments; return new Promise(function (r, o) { var a = n.apply(t, e); function _next(n) { asyncGeneratorStep(a, r, o, _next, _throw, "next", n); } function _throw(n) { asyncGeneratorStep(a, r, o, _next, _throw, "throw", n); } _next(void 0); }); }; }
/**
 * Class dealing with the /transfers endpoint
 *
 * @export
 * @class Transfers
 */
class Transfers {
  constructor(config) {
    this.config = config;
  }

  /**
   * Initiate a transfer of funds from source entity to destination entity.
   *
   * @memberof Transfers
   * @param {Object} body Transfers request body.
   * @param {string} [idempotencyKey] Idempotency Key.
   * @return {Promise<Object>} A promise to the request transfers response.
   */
  initiate(body, idempotencyKey) {
    var _this = this;
    return _asyncToGenerator(function* () {
      try {
        const url = `${_this.config.host.includes('sandbox') ? _config.TRANSFERS_SANDBOX_URL : _config.TRANSFERS_LIVE_URL}`;
        const response = yield (0, _http.post)(_this.config.httpClient, url, _this.config, _this.config.sk, body, idempotencyKey);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }

  /**
   * Retrieve transfer details using the transfer identifier.
   *
   * @memberof Transfers
   * @param {string} id tra_XXX The transfer identifier.
   * @return {Promise<Object>} A promise to the transfer response.
   */
  retrieve(id) {
    var _this2 = this;
    return _asyncToGenerator(function* () {
      try {
        const url = `${_this2.config.host.includes('sandbox') ? _config.TRANSFERS_SANDBOX_URL : _config.TRANSFERS_LIVE_URL}/${id}`;
        const response = yield (0, _http.get)(_this2.config.httpClient, url, _this2.config, _this2.config.sk);
        return yield response.json;
      } catch (err) {
        const error = yield (0, _errors.determineError)(err);
        throw error;
      }
    })();
  }
}
exports.default = Transfers;
//# sourceMappingURL=transfers.js.map